@@ -6,14 +6,14 @@ import logging
 logger = logging.getLogger()
 
 
-def encrypt_text_with_kms(config_dict, key_id, kms_client=None):
+def encrypt_text_with_kms(config_dict, ssm_key_alias, kms_client=None):
     if kms_client is None:
         kms_client = boto3.client('kms',
                                   aws_access_key_id=None,
                                   aws_secret_access_key=None
                                   )
     config_text = json.dumps(config_dict)
-    key = 'alias/%s' % key_id
+    key = 'alias/%s' % ssm_key_alias
     try:
         response = kms_client.encrypt(
             KeyId=key,
